==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/imagelink/image-expander-dom-visitor-provider.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "image-expander.h"

#include "image-expander-dom-visitor-provider.h"

ImageExpanderDomVisitorProvider::ImageExpanderDomVisitorProvider()
{
	Visitor.reset(new IgnoreLinksDomVisitor(new ImageExpander()));
}

ImageExpanderDomVisitorProvider::~ImageExpanderDomVisitorProvider()
{
}

DomVisitor * ImageExpanderDomVisitorProvider::provide() const
{
	return Configuration.showImages() ? Visitor.data() : 0;
}

void ImageExpanderDomVisitorProvider::setConfiguration(const ImageLinkConfiguration &configuration)
{
	Configuration = configuration;
}

#include "moc_image-expander-dom-visitor-provider.cpp"

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/imagelink/image-expander-dom-visitor-provider.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "image-expander-dom-visitor-provider.h"

#include "image-expander.h"

#include "misc/memory.h"

ImageExpanderDomVisitorProvider::ImageExpanderDomVisitorProvider(QObject *parent) :
		QObject{parent},
		m_ignoreLinksVisitor{std::make_unique<ImageExpander>()}
{
}

ImageExpanderDomVisitorProvider::~ImageExpanderDomVisitorProvider()
{
}

const DomVisitor * ImageExpanderDomVisitorProvider::provide() const
{
	return m_configuration.showImages() ? &m_ignoreLinksVisitor : nullptr;
}

void ImageExpanderDomVisitorProvider::setConfiguration(const ImageLinkConfiguration &configuration)
{
	m_configuration = configuration;
}

#include "moc_image-expander-dom-visitor-provider.cpp"
